@@ -1,6 +1,6 @@
 package ClearCase::Wrapper;
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 require 5.004;
 
@@ -18,7 +18,7 @@ BEGIN {
 use constant MSWIN => $^O =~ /MSWin32|Windows_NT/i ? 1 : 0;
 
 # This is the list of functions we want to export to overlay pkgs.
-@exports = qw(MSWIN GetOptions Msg Pred ViewTag
+@exports = qw(MSWIN GetOptions Assert Msg Pred ViewTag
 		    AutoCheckedOut AutoNotCheckedOut AutoViewPrivate);
 
 # Hacks for portability with Windows env vars.
@@ -243,6 +243,24 @@ if (-r "$ENV{HOME}/.clearcase_profile.pl" && ! -e "$libdir/NO_OVERRIDES") {
     require "$ENV{HOME}/.clearcase_profile.pl";
 }
 
+# Returns a boolean indicating whether the named cmd is native to CC
+# cmd or not. Note: the first call to this func has a cost of one
+# "cleartool help" operation; subsequent calls are free.
+{
+    my %native;
+    sub Native {
+	my $op = shift;
+	if (! $op) {
+	    ($op = (caller(1))[3]) =~ s%.*:%%;
+	}
+	if (! keys %native) {
+	    %native = map {/^\S+\s+(\S+)/; $1 => 1} grep /^Usage:/,
+						    ClearCase::Argv->help->qx;
+	}
+	return $native{$op};
+    }
+}
+
 # This is an enhancement like the ones below but is kept "above the
 # fold" because wrapping of cleartool man is an integral and generic
 # part of the module. It runs "cleartool man <cmd>" as requested,
@@ -293,6 +311,7 @@ synthesized.
 ## Internal service routines, autoloaded since not always needed.
 ###########################################################################
 
+# For standard format error msgs - see code for examples.
 sub Msg {
     my $key = shift;
     my $type = {W=>'Warning', E=>'Error'}->{$key} if $key;
@@ -307,6 +326,19 @@ sub Msg {
     return "$msg\n";
 }
 
+# Allows the extension writer to make an assertion. If this assertion
+# is untrue, dump the current command's usage msg to stderr and exit.
+sub Assert {
+    my $assertion = shift;
+    return if $assertion;
+    (my $op = (caller(1))[3]) =~ s%.*:%%;
+    no strict 'refs';
+    my $str = ${$op};
+    my $star = '*' unless Native($op);
+    print STDERR "Usage: $star$str\n";
+    exit 1;
+}
+
 # Recursive function to find the n'th predecessor of a given version.
 sub Pred {
     my($vers, $count, $ct) = @_;
